@@ -1,5 +1,5 @@
 cBohnWolfe<-function(alpha,k,q,c,d,method="Monte Carlo",n.mc=10000){
-  if(alpha>1||alpha<0||class(alpha)!="numeric"){
+  if(alpha>1||alpha<0||!is.numeric(alpha)){
     cat('Error: Check alpha value! \n')
     return(alpha)
   }
