@@ -21,7 +21,7 @@ cDurSkiMa<-function(alpha,obs.mat, method=NA, n.mc=10000){
   
   outp$lambda<-outp$pp*(outp$ss-1)/(outp$k-1)
   
-  if(alpha>1||alpha<0||class(alpha)!="numeric"){
+  if(alpha>1||alpha<0||!is.numeric(alpha)){
     cat('Error: Check alpha value! \n')
     return(alpha)
   }
